/*
Local INdex maker "LIN" & "LIN-Win" (C) 1999-2013 Tatsuhiko Shoji
The sources for Local INdex maker "LIN" & "LIN-Win" are distributed under the MIT open source license
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <io.h>
#include <time.h>
#include	<windows.h>
#include <direct.h>
#include <locale.h>

#include	"lin.h"

char *progTitle = "@(#)Local INdex maker \"LIN\" Version 1.45 By Tatsuhiko Syoji(Tatsu) 1999-2013\n";

void ErrorMessage(char *mes)
{
	fprintf(stdout,mes);
}

/* IvVߕ */
void Usage(unsigned char *programName)
{
	fprintf(stderr,"%s usage:\n",programName);
	/* Modify here to add your usage message when the program is
	 * called without arguments */
	fprintf(stderr,progTitle + 4);
	fprintf(stderr,"LIN [Search directory] [Options...]\n");
	fprintf(stderr,"Options:\n-D Output Directory name\n-F filename : Output file name\n-R : Reverse order output\n-S [0-4] : Sort type 0:none 1:title 2:filename 3:time 4:size\n-T [0-3] : HTML Type 0:Normal 1:Table 2:Frame 3:Double Window\n-L Link in subdirectory's local index file\n-E rEcursive search\n");
	fprintf(stderr,"-I Ignore IE5 .files directory\n-M Ignore Firefox/Opera/Chrome _files directory\n-C Output to console\n-N index file title Name\n-nofile:Don't output file name\n-notime:Don't output time stamp\n-nosize:Don't output file size\n-A Output absolute path name\n-X eXclude local index file name\n-O link not supported type files\n");
	fprintf(stderr,"-cssfile CSS filename\n");
	fprintf(stderr,"-EI specify stylesheet file for every index file.\n");
	fprintf(stderr,"-hd Hide data(.files/_files) directory.\n");
	fprintf(stderr,"-?,-help : Display this\n");
	exit(1);
}

/* returns the index of the first argument that is not an option; i.e.
   does not start with a dash or a slash
*/
int HandleOptions(int argc,unsigned char *argv[])
{
	int i,firstnonoption=0;

	outfile = "LocalIndex.html";	// default output

	for (i=1; i< argc;i++) {
		if (argv[i][0] == '/' || argv[i][0] == '-') {
			switch (toupper(argv[i][1])) {
				/* An argument -? means help is requested */
				case '?':
					Usage(argv[0]);
					break;
				case 'H':
					if (!stricmp(argv[i]+1,"help")) {
						Usage(argv[0]);
						break;
					}
					/* If the option -h means anything else
					 * in your application add code here
					 * Note: this falls through to the default
					 * to print an "unknow option" message
					*/
					if (!stricmp(argv[i]+1,"hd")) {
						hideDataDir = 1;
						break;
					}
					break;
				/* add your option switches here */
				case 'A':
					absLink = 1;
					break;
				case 'C':
					if (!strcmp(argv[i]+1,"cssfile")){
						if ((i+1) < argc){
							i++;
							if (argv[i][0] != '-' && argv[i][0] != '/'){
								stylesheet = argv[i];
							}else{
								i--;
							}
						}
						break;
					}
					outfile = NULL;
					break;
				case 'E':
					if (!stricmp(argv[i]+1,"ei")){
						topStyle = 1;
						break;
					}
					recSearch = 1;
					break;
				case 'F':
					if (argv[i][2]){
						outfile = argv[i]+2;
					}else{
						if ((i+1) < argc){
							i++;
							if (argv[i][0] != '-' && argv[i][0] != '/'){
								outfile = argv[i];
							}else{
								i--;
								outfile = "LocalIndex.html";
							}
						}else{
							outfile = "LocalIndex.html";
						}
					}
					break;
				case 'D':
					subdir = 1;
				break;
				case 'R':
					dispreverse = 1;
				break;
				case 'S':
					if (argv[i][2]){
						sorttype = atoi(argv[i]+2);
					}else{
						if ((i+1) < argc){
							i++;
							sorttype = atoi(argv[i]);
						}
					}
					if (sorttype < 0 || sorttype > 4){ /* 0:Nothing 1:Title 2:Filename 3:time stamp 4:size */
						fprintf(stderr,"Bad sort type.\n",argv[i]);
						exit(1);
					}
				break;
				case 'T':
					if (argv[i][2]){
						HTMLtype = atoi(argv[i]+2);
					}else{
						if ((i+1) < argc){
							i++;
							HTMLtype = atoi(argv[i]);
						}
					}
					if (HTMLtype < 0 || HTMLtype > 3){ /* 0:Normal 1:Table 2:Frame 3:Double Window */
						fprintf(stderr,"Bad HTML type.\n",argv[i]);
						exit(1);
					}
				break;
				case 'L':
					dirlink = 1;
				break;
				case 'I':
					ie5 = 1;
				break;
				case 'M':
					Mozilla = 1;
				break;
				case 'O':
					other = 1;
				break;
				case 'N':
					if (!strcmp(argv[i]+1,"nofile")){
						out_fname = 0;
						break;
					}
					if (!strcmp(argv[i]+1,"notime")){
						out_time = 0;
						break;
					}
					if (!strcmp(argv[i]+1,"nosize")){
						out_size = 0;
						break;
					}

					if ((i+1) < argc){
						i++;
						if (argv[i][0] != '-' && argv[i][0] != '/'){
							indextitle = argv[i];
						}else{
							i--;
						}
					}
					break;
				case 'X':
					exclude = 1;
				break;
				default:
					fprintf(stderr,"unknown option %s\n",argv[i]);
					exit(1);
				break;
			}
		}
		else firstnonoption = i;
	}
	return firstnonoption;
}

int main(int argc,unsigned char *argv[])
{
	int dirarg,len;

	bm_top = bm_end = bm_base =NULL;

	/* handle the program options */
	dirarg = HandleOptions(argc,argv);
	/* The code of your application goes here */

	setlocale(LC_ALL,".ACP");	/* P[N[U[̐ݒŏB */

	if (dirarg){
		strcpy(dir,argv[dirarg]);
	}else{
		getcwd(dir,DIRBUF);
//		dir[0] = '\0';
	}

	len = strlen(dir);
	if (dir[len-1] != '\\'){
		strcat(dir,"\\");
		//len++;
	}

	/* fBNgJn */
	main2(dir,(struct dir_config *)NULL,(struct dir_config *)NULL);

	return 0;
}

